@@ -19,14 +19,11 @@
 #include <libxml/parserInternals.h>
 #include <libxml/catalog.h>
 
-#include <QDate>
 #include <QDir>
 #include <QFile>
-#include <QRegExp>
 #include <QStandardPaths>
 #include <QTextCodec>
 #include <QUrl>
-#include <QDebug>
 #include <QByteArray>
 #include <QString>
 #include <QVector>
@@ -292,7 +289,6 @@ QString splitOut(const QString &parsed, int index)
         filedata = filedata.left(index) + filedata.mid(endindex);
     }
 
-    // filedata.replace(QRegExp(">"), "\n>");
     return filedata;
 }
 
@@ -330,8 +326,7 @@ QByteArray fromUnicode(const QString &data)
                 strcpy(buffer + buffer_len, test.data());
                 buffer_len += test.length();
             } else {
-                QString res;
-                res.sprintf("&#%d;", part.at(i).unicode());
+                QString res = QStringLiteral("&#%1;").arg(part.at(i).unicode());
                 test = locale->fromUnicode(res);
                 if (buffer_len + test.length() + 1 > sizeof(buffer)) {
                     break;
